import requests
from io import BytesIO
from urllib.parse import urlparse

from django.conf import settings
from django.core.files.storage import DefaultStorage
from django.http import Http404
from django.http import HttpResponse
from django.views.decorators.http import require_safe


def process_options(options):
    parameters = {}
    options = options or ''
    for pair in options.split(';'):
        key, value = pair.split(',', maxsplit=1)
        parameters[key] = value
    return parameters


@require_safe
def image_view(request, path=None, options=None):
    if not path:
        raise Http404('No path provided')

    # Grab the default storage, to build the URL
    storage = DefaultStorage()

    # Optionaly check if the file exists in the storage
    # Depending on your storage class, this might not be implemented or performs something outrageous like loading
    # the entire file into memory
    if getattr(settings, 'RSZIO_CHECK_EXISTS', False) and not storage.exists(path):
        raise Http404('Image not found in storage')

    # Get the full URL for the image
    original_url = storage.url(path)

    # Use urllip to pull out the host and path
    parsed_url = urlparse(original_url)

    # Build the URL
    url = 'https://rsz.io/{host}{path}'.format(
        host=parsed_url.hostname,
        path=parsed_url.path,
    )

    # Build the rsz.io parameters
    try:
        parameters = process_options(options)
    except:
        # KISS: if invalid parameters are passed, raise a 404
        raise Http404('Invalid rsz.io options')

    # Grab the image
    rszio_response = requests.get(url, parameters)

    # Return
    buffer_image = BytesIO(rszio_response.content)
    buffer_image.seek(0)
    response = HttpResponse(buffer_image, content_type=rszio_response.headers['content-type'])

    # Set cache headers
    if hasattr(settings, 'RSZIO_CACHE_CONTROL'):
        try:
            response['Cache-Control'] = 'max-age={}'.format(int(settings.RSZIO_CACHE_CONTROL))
        except:
            response['Cache-Control'] = settings.RSZIO_CACHE_CONTROL

    return response



from django import template
from django.conf import settings
from django.urls import reverse


register = template.Library()


@register.simple_tag
def image(img, **kwargs):
    if not img:
        if settings.DEBUG:
            raise ValueError('No image path defined')
        return ''

    # Convert the kwargs to an appropriate string
    options = []
    for key, value in kwargs.items():
        options.append('{key},{value}'.format(key=key, value=value))

    return reverse('rszio_image', kwargs={
        'options': ';'.join(options),
        'path': img,
    })



#!/usr/bin/env python
from distutils.core import setup
from setuptools import find_packages
from rszio import version

try:
    from pypandoc import convert
    read_md = lambda f: convert(f, 'rst')  # noqa
except ImportError:
    read_md = lambda f: open(f, 'r').read()  # noqa

setup(
    name='django-rszio',
    author='Chad Shryock',
    author_email='chad@keystone.works',
    description='Django wrapper for RSZ.IO',
    long_description=read_md('README.md'),
    license='MIT',
    version=version,
    packages=find_packages(),
    include_package_data=True,
    url='https://github.com/g3rd/django-rszio',
    zip_safe=True,
    install_requires=[
        'django>=1.10',
        'requests>=2.14.2',
    ],
    classifiers=[
        'Framework :: Django',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='django resize image',
)
